defmodule PrymnWeb.ServerLiveTest do
  use PrymnWeb.ConnCase

  import Phoenix.LiveViewTest
  import Prymn.ServersFixtures

  @create_attrs %{name: "some name"}
  @update_attrs %{name: "some updated name"}
  @invalid_attrs %{name: nil}

  defp create_server(_) do
    server = server_fixture()
    %{server: server}
  end

  describe "Index" do
    setup [:create_server]

    test "lists all servers", %{conn: conn, server: server} do
      {:ok, _index_live, html} = live(conn, ~p"/servers")

      assert html =~ "Listing Servers"
      assert html =~ server.name
    end

    test "saves new server", %{conn: conn} do
      {:ok, index_live, _html} = live(conn, ~p"/servers")

      assert index_live |> element("a", "Connect a Server") |> render_click() =~
               "Add a new server"

      assert_patch(index_live, ~p"/servers/new")

      assert index_live
             |> form("#server-form", server: @invalid_attrs)
             |> render_change() =~ "can&#39;t be blank"

      assert index_live
             |> form("#server-form", server: @create_attrs)
             |> render_submit()

      assert_patch(index_live, ~p"/servers")

      html = render(index_live)
      assert html =~ "Server created successfully"
      assert html =~ "some name"
    end

    test "deletes server in listing", %{conn: conn, server: server} do
      {:ok, index_live, _html} = live(conn, ~p"/servers")

      assert index_live |> element("#servers-#{server.id} a", "Delete") |> render_click()
      refute has_element?(index_live, "#servers-#{server.id}")
    end
  end

  describe "Show" do
    setup [:create_server]

    test "displays server", %{conn: conn, server: server} do
      {:ok, _show_live, html} = live(conn, ~p"/servers/#{server}")

      assert html =~ "Server some name"
    end
  end

  describe "Edit" do
    setup [:create_server]

    test "updates server", %{conn: conn, server: server} do
      {:ok, edit_live, _html} = live(conn, ~p"/servers/#{server}/edit")

      assert edit_live
             |> form("#server-form", server: @invalid_attrs)
             |> render_change() =~
               "can&#39;t be blank"

      assert edit_live
             |> form("#server-form", server: @update_attrs)
             |> render_submit()

      html = render(edit_live)
      assert html =~ "some updated name"
    end
  end
end
